@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-"""For information of MolDrug:
+"""
+For information of MolDrug:
     Docs: https://moldrug.readthedocs.io/en/latest/
     Source Code: https://github.com/ale94mleon/moldrug
 """
 from moldrug._version import __version__, __version_tuple__
+
 __author__ = "Alejandro Martínez León"
 __email__ = "ale94mleon@gmail.com"
\ No newline at end of file
